/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
/**
 * Interface for a job dd
 * Represents the name and details of an output (spool) DD
 * for a z/OS batch job
 * @export
 * @interface IJobFile
 */
export interface IJobFile {
    /**
     * job id for a job
     * Uniquely identifies a job on a z/OS system
     * @type {string}
     * @memberof IJob
     */
    jobId?: string;
    /**
     * job name for a job
     * @type {string}
     * @memberof IJob
     */
    jobName?: string;
    /**
     * Total records (roughly equivalent to lines) in the spool file
     * @type {number}
     * @memberof IJobFile
     */
    recordCount: number;
    /**
     * Identifier for this spool file
     * each IJobFile for a single batch job will have a unique ID
     * @type {number}
     * @memberof IJobFileSimple
     */
    id: number;
    /**
     * DD name of job spool file
     * @type {string}
     * @memberof IJobFileSimple
     */
    ddName: string;
    /**
     * The name of the job step during which this spool file was produced
     * @type {string}
     * @memberof IJobFileSimple
     */
    'step name': string;
    /**
     * If this spool file was produced during a job procedure step, the
     * name of the step will be here.
     * @type {string}
     * @memberof IJobStepData
     */
    'proc step': string;
    date: string;
    timestamp: string;
}
