/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session, IProfile } from '@zowe/imperative';
import * as zowe from '@zowe/cli';
import { IRestApiResponse } from '../../doc/IRestApiResponse';
import { IJobFile } from '../../doc';
import { IDownloadRseOptions } from './doc/IDownloadRseOptions';
/**
 * This class holds helper functions that are used to download data sets, members and more through the RSE APIs
 */
export declare class GetContent {
    /**
     * Retrieve USS file content to save it in your local workspace.
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           ussFileName  - contains the USS file name
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     *
     * @returns {Promise<IRestApiResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} USS file name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     */
    static ussFile(session: Session, ussFileName: string, options: Partial<IDownloadRseOptions>): Promise<IRestApiResponse>;
    /**
     * Retrieve Dataset Member content to save it in your local workspace.
     *
     * @param {Session}          session      - RSE connection info
     * @param {string}           ussFileName  - contains the USS file name
     * @param {IDownloadOptions} [options={}] - contains the options to be sent
     *
     * @returns {Promise<IRestApiResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} Dataset Member file name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     */
    static dataSet(session: Session, dataSetName: string, profile: IProfile, options?: IDownloadRseOptions): Promise<IRestApiResponse>;
    static dataSetBinary(session: Session, dataSetName: string, options?: IDownloadRseOptions): Promise<IRestApiResponse>;
    /**
     * Retrieve Job Spool content to save it in your local workspace.
     *
     * @param {Session}                     session      - RSE connection info
     * @param {IDownloadSpoolContentParms}  [options={}] - contains the options to be sent
     *
     * @returns {Promise<IRestApiResponse>} A response indicating the outcome of the API
     *
     * @throws {ImperativeError} Dataset Member file name must be set
     * @throws {Error} When the {@link RseRestClient} throws an error
     */
    static jobOutput(session: Session, jobFile: IJobFile, parms?: zowe.IDownloadSpoolContentParms): Promise<IRestApiResponse>;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
