/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as imperative from '@zowe/imperative';
import { ZoweExplorerApi } from '@zowe/zowe-explorer-api/lib/profiles';
/**
 * The API register is a different instance than the Zowe Explorer VS Code extension
 * register singleton. It is a non-singleton class that can be used by other applications
 * that do not use Zowe Explorer to register and use APIs.
 * Example for registering:
 *    const secondaryRestApiRegister = new SecondaryRestApiRegister();
 *    secondaryRestApiRegister.registerUssApi(new ZoweVscZosmfUssRestApi());
 *    secondaryRestApiRegister.registerUssApi(new ZoweVscRseUssRestApi());
 *
 * @export
 * @class SecondaryRestApiRegister
 * @implements ZoweExplorerApi.IApiRegisterClient
 */
export declare class SecondaryRestApiRegister implements ZoweExplorerApi.IApiRegisterClient {
    private zoweVscUssApiImplementations;
    private zoweVscMvsApiImplementations;
    private zoweVscJesApiImplementations;
    private zoweVscCommandApiImplementations;
    /**
     * Other VS Code extension need to call this to register their USS APIs.
     * @param {ZoweExplorerApi.IUss} ussApi
     */
    registerUssApi(ussApi: ZoweExplorerApi.IUss): void;
    /**
     * Other VS Code extension need to call this to register their MVS APIs.
     * @param {ZoweExplorerApi.IUss} mvsApi
     */
    registerMvsApi(mvsApi: ZoweExplorerApi.IMvs): void;
    registerJesApi(jesApi: ZoweExplorerApi.IJes): void;
    registerCommandApi(commandApi: ZoweExplorerApi.ICommand): void;
    /**
     * Get an array of all the registered APIs identified by the CLI profile types,
     * such as ["zosmf", "ftp"].
     * @returns {string[]}
     */
    registeredApiTypes(): string[];
    /**
     * Get an array of all the registered USS APIs identified by the CLI profile types,
     * such as ["zosmf", "ftp"].
     * @returns {string[]}
     */
    registeredUssApiTypes(): string[];
    /**
     * Get an array of all the registered MVS APIs identified by the CLI profile types,
     * such as ["zosmf", "zftp"].
     * @returns {string[]}
     */
    registeredMvsApiTypes(): string[];
    /**
     * Get an array of all the registered JES APIs identified by the CLI profile types,
     * such as ["zosmf", "zftp"].
     * @returns {string[]}
     */
    registeredJesApiTypes(): string[];
    /**
     * Get an array of all the registered Command APIs identified by the CLI profile types,
     * such as ["zosmf", "zftp"].
     * @returns {string[]}
     */
    registeredCommandApiTypes(): string[];
    /**
     * Lookup of an API for USS for a given profile.
     * @private
     * @param {imperative.IProfileLoaded} profile
     * @returns
     * @memberof ZoweExplorerApiRegister
     */
    getUssApi(profile: imperative.IProfileLoaded): ZoweExplorerApi.IUss;
    getMvsApi(profile: imperative.IProfileLoaded): ZoweExplorerApi.IMvs;
    getJesApi(profile: imperative.IProfileLoaded): ZoweExplorerApi.IJes;
    getCommandApi(profile: imperative.IProfileLoaded): ZoweExplorerApi.ICommand;
    getExplorerExtenderApi(): ZoweExplorerApi.IApiExplorerExtender;
}
