/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import * as imperative from '@zowe/imperative';
import { SecondaryRestApiRegister } from './SecondaryRestApiRegister';
export declare class ZoweCliProfiles {
    log: imperative.Logger;
    static getInstance(): Promise<ZoweCliProfiles>;
    private static loader;
    static createInstance(log: imperative.Logger): Promise<ZoweCliProfiles>;
    apiRegistry: SecondaryRestApiRegister;
    allProfiles: imperative.IProfileLoaded[];
    private profilesByType;
    private defaultProfileByType;
    private profileManagerByType;
    private constructor();
    loadNamedProfile(name: string, type?: string): imperative.IProfileLoaded | undefined;
    /**
     * @param {string} [type="zosmf"]
     * @returns {(imperative.IProfileLoaded | undefined)}
     *      The default profile of the given type with zosmf as the default type.
     */
    getDefaultProfile(type?: string): imperative.IProfileLoaded | undefined;
    /**
     * @returns {(imperative.IProfileLoaded | undefined)}
     *      The default profile with a preference for RSE REST profiles over zOSMF.
     * @memberof ZoweCliProfiles
     */
    getPreferredDefaultProfile(): imperative.IProfileLoaded | undefined;
    getProfiles(type?: string): imperative.IProfileLoaded[];
    getCombinedProfile(zoweProfile: imperative.IProfileLoaded): imperative.IProfileLoaded;
    getSchema(profileType: string): Record<string, unknown>;
    refresh(): Promise<void>;
    getCliProfileManager(type: string): imperative.CliProfileManager;
    checkProfileToken(session: imperative.Session, params: imperative.IHandlerParameters, profile: imperative.IProfile): Promise<imperative.Session>;
    static isSecureCredentialPluginActive(): boolean;
    /**
     * Function to retrieve the home directory. In the situation Imperative has
     * not initialized it we mock a default value.
     */
    private static getZoweDir;
    /**
     * Get Log
     * @returns {Logger} applicationLogger.
     */
    private static get log();
}
