/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
import { Session, HTTP_VERB, IImperativeError, RestClient } from '@zowe/imperative';
import { IStringWithEtag } from '../doc';
import { IAuthorizationToken } from '../doc/IAuthorizationTokenResponse';
/**
 * Wrapper for invoking calls against the Zowe REST API through the
 * Imperative RestClient to perform common error handling
 * and checking and resolve promises according to generic types
 * @export
 * @class RestRestClient
 * @extends {RestClient}
 */
export declare class RseRestClient extends RestClient {
    /**
     * Use the Zowe logger instead of the imperative logger
     * @return {Logger}
     */
    private static get log();
    static getExpectBufferAndEtag(session: Session, resource: string, reqHeaders?: any[]): Promise<IStringWithEtag>;
    static putExpectStringAndEtag(session: Session, resource: string, reqHeaders: any[], data: any): Promise<IStringWithEtag>;
    static postExpectAuthToken(session: Session, resource: string, reqHeaders: any[], payload: any): Promise<IAuthorizationToken>;
    /**
     * Internal logger
     */
    private static mLogger;
    private static readonly ACCEPT_APPLICATION_JSON;
    /**
     * Overridden performRest method implemented to append hostname, port, and plex headers to all IMS requests
     * Takes the same parameters as the vanilla Imperative 'performRest' method.
     * @param resource
     * @param request
     * @param reqHeaders
     * @param writeData
     */
    performRest(resource: string, request: HTTP_VERB, reqHeaders?: any[], writeData?: any): Promise<string>;
    /**
     * Append Zowe REST specific headers to the callers headers for cases
     * where a header is common to every request.
     * @param {any[] | undefined} headers - current header array
     * @memberof ZoweRestRestClient
     */
    protected appendHeaders(headers: any[] | undefined): any[];
    /**
     * Process an error encountered in the rest client
     * @param {IImperativeError} original - the original error automatically built by the abstract rest client
     * @returns {IImperativeError} - the processed error with details added
     */
    protected processError(original: IImperativeError): IImperativeError;
}
