/*
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2020, 2021. All Rights Reserved.
 *
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *
 */
/// <reference types="node" />
import * as imperative from '@zowe/imperative';
import { IHeaderContent } from '../doc/IHeaderContent';
/**
 * Adds padding in case you want a longer string.
 *
 * @param {string} str              - string to add the padding to
 * @param {number} len              - final length of the padded string
 * @param {string} [padChar=" "]    - Padding character
 * @return {string} Padded string
 */
export declare function padLeft(str: string, len: number, padChar?: string): string;
/**
 * This is a simple sleep function to help when waiting for a certain period of
 * time before continuing.
 *
 * @param {number} [ms=1000] The number of milliseconds to sleep.
 *
 * @returns {Promise<void>} Resolves after the specified time is up.
 *
 * @example <caption>Sleeping within code</caption>
 *
 * async function doStuff() {
 *   await CoreUtils.sleep(10000);
 *   console.log("You will see this message 10 seconds after function was entered");
 * }
 */
export declare function sleep(ms?: number): Promise<void>;
/**
 * Utility function to read complete standard in contents from a handler
 * Can be awaited from async methods
 */
export declare function readStdin(): Promise<Buffer>;
/**
 * Execute multiple promises in a pool with a maximum number of promises
 * executing at once
 * @param poolLimit - limit of how many promises should execute at once
 * @param array - array of objects to convert to promises with iteratorFn
 * @param iteratorFn - the function that turns an entry in the array into a promise
 */
export declare function asyncPool(poolLimit: number, array: any[], iteratorFn: (item: any, array: any[]) => Promise<any>): Promise<any>;
export declare function updateYaml(profileName: string, updateInfo: imperative.IProfile): Promise<imperative.IProfileUpdated>;
export declare function saveYaml(profileName: string, updateInfo: imperative.IProfile): Promise<imperative.IProfileUpdated>;
export declare function checkForToken(session: imperative.Session): {
    Authorization: string;
};
export declare function setUnixRestCommandFullHeaders(session: imperative.Session): {
    Authorization: string;
};
export declare function setHeaders(session: imperative.Session): IHeaderContent[];
export declare function compareProfiles(profile: imperative.IProfile, itemProfile: imperative.IProfile): boolean;
export declare function getUserHome(): unknown;
export declare function getZoweDir(): string;
export declare function getDefaultProfile(): Promise<imperative.IProfileLoaded>;
export declare function apiVersionCheck(session: imperative.Session, version: number): Promise<void>;
export declare function readLocalFile(filePath: string): Promise<string>;
export declare function getProfileMeta(): Promise<imperative.ICommandProfileTypeConfiguration[]>;
